@@ -3,6 +3,7 @@
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "attachmentmodel.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include "mimetreeparser_core_debug.h"
 
@@ -37,10 +38,10 @@ namespace
 QString sizeHuman(float size)
 {
     QStringList list;
-    list << QStringLiteral("KB") << QStringLiteral("MB") << QStringLiteral("GB") << QStringLiteral("TB");
+    list << u"KB"_s << u"MB"_s << QStringLiteral("GB") << QStringLiteral("TB");
 
     QStringListIterator i(list);
-    QString unit = QStringLiteral("Bytes");
+    QString unit = u"Bytes"_s;
 
     while (size >= 1024.0 && i.hasNext()) {
         unit = i.next();
@@ -48,9 +49,9 @@ QString sizeHuman(float size)
     }
 
     if (unit == QLatin1StringView("Bytes")) {
-        return QString().setNum(size) + QStringLiteral(" ") + unit;
+        return QString().setNum(size) + u" "_s + unit;
     } else {
-        return QString().setNum(size, 'f', 2) + QStringLiteral(" ") + unit;
+        return QString().setNum(size, 'f', 2) + u" "_s + unit;
     }
 }
 
@@ -65,14 +66,14 @@ QString sizeHuman(float size)
 //  names.
 const QRegularExpression &windowsDeviceNoSubDirPattern()
 {
-    static const QRegularExpression rc(QStringLiteral("^" WINDOWS_DEVICES_PATTERN "$"), QRegularExpression::CaseInsensitiveOption);
+    static const QRegularExpression rc(u"^" WINDOWS_DEVICES_PATTERN "$"_s, QRegularExpression::CaseInsensitiveOption);
     Q_ASSERT(rc.isValid());
     return rc;
 }
 
 const QRegularExpression &windowsDeviceSubDirPattern()
 {
-    static const QRegularExpression rc(QStringLiteral("^.*[/\\\\]" WINDOWS_DEVICES_PATTERN "$"), QRegularExpression::CaseInsensitiveOption);
+    static const QRegularExpression rc(u"^.*[/\\\\]" WINDOWS_DEVICES_PATTERN "$"_s, QRegularExpression::CaseInsensitiveOption);
     Q_ASSERT(rc.isValid());
     return rc;
 }
@@ -185,12 +186,12 @@ AttachmentModel::~AttachmentModel()
 QHash<int, QByteArray> AttachmentModel::roleNames() const
 {
     return {
-        {TypeRole, QByteArrayLiteral("type")},
-        {NameRole, QByteArrayLiteral("name")},
-        {SizeRole, QByteArrayLiteral("size")},
-        {IconRole, QByteArrayLiteral("iconName")},
-        {IsEncryptedRole, QByteArrayLiteral("encrypted")},
-        {IsSignedRole, QByteArrayLiteral("signed")},
+        {TypeRole, "type"_ba},
+        {NameRole, "name"_ba},
+        {SizeRole, "size"_ba},
+        {IconRole, "iconName"_ba},
+        {IsEncryptedRole, "encrypted"_ba},
+        {IsSignedRole, "signed"_ba},
     };
 }
 
@@ -285,7 +286,7 @@ QString AttachmentModel::saveAttachmentToPath(const MimeTreeParser::MessagePart:
 {
     Q_ASSERT(part);
     auto node = part->node();
-    auto data = node->decodedContent();
+    auto data = node->decodedBody();
     // This is necessary to store messages embedded messages (EncapsulatedRfc822MessagePart)
     if (data.isEmpty()) {
         data = node->encodedContent();
@@ -316,7 +317,7 @@ bool AttachmentModel::openAttachment(const int row)
 bool AttachmentModel::openAttachment(const MimeTreeParser::MessagePart::Ptr &message)
 {
     QString fileName = message->filename();
-    QTemporaryDir tempDir(QDir::tempPath() + QLatin1Char('/') + qGuiApp->applicationName() + QStringLiteral(".XXXXXX"));
+    QTemporaryDir tempDir(QDir::tempPath() + QLatin1Char('/') + qGuiApp->applicationName() + u".XXXXXX"_s);
     // TODO: We need some cleanup here. Otherwise the files will stay forever on Windows.
     tempDir.setAutoRemove(false);
     if (message->filename().isEmpty() || !validateFileName(fileName, false)) {
@@ -373,7 +374,7 @@ bool AttachmentModel::importPublicKey(const int row)
 bool AttachmentModel::importPublicKey(const MimeTreeParser::MessagePart::Ptr &part)
 {
     Q_ASSERT(part);
-    const QByteArray certData = part->node()->decodedContent();
+    const QByteArray certData = part->node()->decodedBody();
     QGpgME::ImportJob *importJob = QGpgME::openpgp()->importJob();
 
     connect(importJob, &QGpgME::AbstractImportJob::result, this, [this](const GpgME::ImportResult &result) {
@@ -383,7 +384,7 @@ bool AttachmentModel::importPublicKey(const MimeTreeParser::MessagePart::Ptr &pa
         } else {
             QString message = i18ndcp("mimetreeparser", "@info", "one certificate imported", "%1 certificates imported", result.numImported());
             if (result.numUnchanged() != 0) {
-                message += QStringLiteral("\n")
+                message += u"\n"_s
                     + i18ndcp("mimetreeparser",
                               "@info",
                               "one certificate was already imported",
