@@ -27,8 +27,8 @@ class MIMETREEPARSER_WIDGETS_EXPORT MessageViewerDialog : public QDialog
     Q_OBJECT
 
 public:
-    MessageViewerDialog(const QList<KMime::Message::Ptr> &messages, QWidget *parent = nullptr);
-    MessageViewerDialog(const QString &fileName, QWidget *parent = nullptr);
+    explicit MessageViewerDialog(const QList<KMime::Message::Ptr> &messages, QWidget *parent = nullptr);
+    explicit MessageViewerDialog(const QString &fileName, QWidget *parent = nullptr);
     ~MessageViewerDialog() override;
 
     [[nodiscard]] QToolBar *toolBar() const;
